@@ -30,13 +30,13 @@
 #include <panel-applet.h>
 #include <gtk/gtk.h>
 #include <gtk/gtkbox.h>
-#include <libgnomeui/gnome-help.h>
 #include <gdk/gdkkeysyms.h>
-#include <libdbus-watch.h>
 #include <glib-object.h>
 #include <dbus/dbus-glib.h>
 
-#include "../src/gpm-common.h"
+#include "egg-debug.h"
+#include "egg-dbus-monitor.h"
+#include "gpm-common.h"
 
 #define GPM_TYPE_BRIGHTNESS_APPLET		(gpm_brightness_applet_get_type ())
 #define GPM_BRIGHTNESS_APPLET(o)		(G_TYPE_CHECK_INSTANCE_CAST ((o), GPM_TYPE_BRIGHTNESS_APPLET, GpmBrightnessApplet))
@@ -58,7 +58,7 @@ typedef struct{
 	/* connection to g-p-m */
 	DBusGProxy *proxy;
 	DBusGConnection *connection;
-	DbusWatch *watch;
+	EggDbusMonitor *monitor;
 	guint level;
 	/* a cache for panel size */
 	gint size;
@@ -120,7 +120,7 @@ gpm_applet_get_brightness (GpmBrightnessApplet *applet)
 	guint policy_brightness;
 
 	if (applet->proxy == NULL) {
-		printf ("WARNING: not connected\n");
+		egg_warning ("not connected\n");
 		return FALSE;
 	}
 
@@ -129,14 +129,14 @@ gpm_applet_get_brightness (GpmBrightnessApplet *applet)
 				 G_TYPE_UINT, &policy_brightness,
 				 G_TYPE_INVALID);
 	if (error) {
-		printf ("DEBUG: ERROR: %s\n", error->message);
+		egg_debug ("ERROR: %s\n", error->message);
 		g_error_free (error);
 	}
-	if (ret == TRUE) {
+	if (ret) {
 		applet->level = policy_brightness;
 	} else {
 		/* abort as the DBUS method failed */
-		printf ("WARNING: GetBrightness failed!\n");
+		egg_warning ("GetBrightness failed!\n");
 	}
 
 	return ret;
@@ -153,7 +153,7 @@ gpm_applet_set_brightness (GpmBrightnessApplet *applet)
 	gboolean ret;
 
 	if (applet->proxy == NULL) {
-		printf ("WARNING: not connected");
+		egg_warning ("not connected");
 		return FALSE;
 	}
 
@@ -162,12 +162,12 @@ gpm_applet_set_brightness (GpmBrightnessApplet *applet)
 				 G_TYPE_INVALID,
 				 G_TYPE_INVALID);
 	if (error) {
-		printf ("DEBUG: ERROR: %s", error->message);
+		egg_debug ("ERROR: %s", error->message);
 		g_error_free (error);
 	}
-	if (ret == FALSE) {
+	if (!ret) {
 		/* abort as the DBUS method failed */
-		printf ("WARNING: SetBrightness failed!");
+		egg_warning ("SetBrightness failed!");
 	}
 
 	return ret;
@@ -207,9 +207,9 @@ gpm_applet_get_icon (GpmBrightnessApplet *applet)
 						 icon, applet->size - 2, 0, NULL);
 
 	if (applet->icon == NULL) {
-		printf ("WARNING: Cannot find %s!\n", icon);
+		egg_warning ("Cannot find %s!\n", icon);
 	} else {
-		printf ("DEBUG: got icon %s!\n", icon);
+		egg_debug ("got icon %s!\n", icon);
 		/* update size cache */
 		applet->icon_height = gdk_pixbuf_get_height (applet->icon);
 		applet->icon_width = gdk_pixbuf_get_width (applet->icon);
@@ -766,7 +766,7 @@ gpm_applet_dialog_about_cb (BonoboUIComponent *uic, gpointer data, const gchar *
 				     _(license[2]), "\n\n", _(license[3]), "\n", NULL);
 
 	about = (GtkAboutDialog*) gtk_about_dialog_new ();
-	gtk_about_dialog_set_name (about, GPM_BRIGHTNESS_APPLET_NAME);
+	gtk_about_dialog_set_program_name (about, GPM_BRIGHTNESS_APPLET_NAME);
 	gtk_about_dialog_set_version (about, VERSION);
 	gtk_about_dialog_set_copyright (about, _("Copyright \xc2\xa9 2006 Benjamin Canou"));
 	gtk_about_dialog_set_comments (about, GPM_BRIGHTNESS_APPLET_DESC);
@@ -783,7 +783,7 @@ gpm_applet_dialog_about_cb (BonoboUIComponent *uic, gpointer data, const gchar *
 	gtk_widget_show (GTK_WIDGET(about));
 
 	g_free (license_trans);
-	gdk_pixbuf_unref (logo);
+	g_object_unref (logo);
 }
 
 /**
@@ -794,24 +794,7 @@ gpm_applet_dialog_about_cb (BonoboUIComponent *uic, gpointer data, const gchar *
 static void
 gpm_applet_help_cb (BonoboUIComponent *uic, gpointer data, const gchar *verbname)
 {
-	GError *error = NULL;
-	GpmBrightnessApplet *applet = GPM_BRIGHTNESS_APPLET(data);
-	GnomeProgram *program = gnome_program_get ();
-
-	gnome_help_display_with_doc_id (program, "gnome-power-manager",
-					"gnome-power-manager.xml",
-					"applets-brightness", &error);
-	if (error != NULL) {
-		GtkWidget *dialog =
-			gtk_message_dialog_new (GTK_WINDOW (GTK_WIDGET(applet)->parent),
-						GTK_DIALOG_DESTROY_WITH_PARENT,
-						GTK_MESSAGE_ERROR,
-						GTK_BUTTONS_CLOSE,
-						"%s", error->message);
-		gtk_dialog_run (GTK_DIALOG (dialog));
-		gtk_widget_destroy (dialog);
-		g_error_free (error);
-	}
+	gpm_help_display ("applets-brightness");
 }
 
 /**
@@ -823,11 +806,11 @@ gpm_applet_destroy_cb (GtkObject *object)
 {
 	GpmBrightnessApplet *applet = GPM_BRIGHTNESS_APPLET(object);
 
-	if (applet->watch != NULL) {
-		g_object_unref (applet->watch);
+	if (applet->monitor != NULL) {
+		g_object_unref (applet->monitor);
 	}
 	if (applet->icon != NULL) {
-		gdk_pixbuf_unref (applet->icon);
+		g_object_unref (applet->icon);
 	}
 }
 
@@ -846,7 +829,7 @@ brightness_changed_cb (DBusGProxy          *proxy,
 		       guint	            brightness,
 		       GpmBrightnessApplet *applet)
 {
-	printf ("DEBUG: BrightnessChanged detected: %i\n", brightness);
+	egg_debug ("BrightnessChanged detected: %i\n", brightness);
 	applet->level = brightness;
 }
 
@@ -859,18 +842,18 @@ gpm_brightness_applet_dbus_connect (GpmBrightnessApplet *applet)
 	GError *error = NULL;
 
 	if (applet->connection == NULL) {
-		printf ("DEBUG: get connection\n");
+		egg_debug ("get connection\n");
 		g_clear_error (&error);
 		applet->connection = dbus_g_bus_get (DBUS_BUS_SESSION, &error);
 		if (error != NULL) {
-			printf ("WARNING: Could not connect to DBUS daemon: %s", error->message);
+			egg_warning ("Could not connect to DBUS daemon: %s", error->message);
 			g_error_free (error);
 			applet->connection = NULL;
 			return FALSE;
 		}
 	}
 	if (applet->proxy == NULL) {
-		printf ("DEBUG: get proxy\n");
+		egg_debug ("get proxy\n");
 		g_clear_error (&error);
 		applet->proxy = dbus_g_proxy_new_for_name_owner (applet->connection,
 							 GPM_DBUS_SERVICE,
@@ -878,7 +861,7 @@ gpm_brightness_applet_dbus_connect (GpmBrightnessApplet *applet)
 							 GPM_DBUS_INTERFACE_BACKLIGHT,
 							 &error);
 		if (error != NULL) {
-			printf ("WARNING: Cannot connect, maybe the daemon is not running: %s\n", error->message);
+			egg_warning ("Cannot connect, maybe the daemon is not running: %s\n", error->message);
 			g_error_free (error);
 			applet->proxy = NULL;
 			return FALSE;
@@ -901,7 +884,7 @@ gboolean
 gpm_brightness_applet_dbus_disconnect (GpmBrightnessApplet *applet)
 {
 	if (applet->proxy != NULL) {
-		printf ("DEBUG: removing proxy\n");
+		egg_debug ("removing proxy\n");
 		g_object_unref (applet->proxy);
 		applet->proxy = NULL;
 	}
@@ -909,13 +892,13 @@ gpm_brightness_applet_dbus_disconnect (GpmBrightnessApplet *applet)
 }
 
 /**
- * watch_connection_cb:
+ * monitor_connection_cb:
  * @proxy: The dbus raw proxy
  * @status: The status of the service, where TRUE is connected
  * @screensaver: This class instance
  **/
 static void
-watch_connection_cb (DbusWatch           *watch,
+monitor_connection_cb (EggDbusMonitor           *monitor,
 		     gboolean	          status,
 		     GpmBrightnessApplet *applet)
 {
@@ -937,6 +920,8 @@ watch_connection_cb (DbusWatch           *watch,
 static void
 gpm_brightness_applet_init (GpmBrightnessApplet *applet)
 {
+	DBusGConnection *connection;
+
 	/* initialize fields */
 	applet->size = 0;
 	applet->call_worked = TRUE;
@@ -951,10 +936,11 @@ gpm_brightness_applet_init (GpmBrightnessApplet *applet)
                                            GPM_DATA G_DIR_SEPARATOR_S "icons");
 
 
-	applet->watch = dbus_watch_new ();
-	g_signal_connect (applet->watch, "connection-changed",
-			  G_CALLBACK (watch_connection_cb), applet);
-	dbus_watch_assign (applet->watch, DBUS_WATCH_SESSION, GPM_DBUS_SERVICE);
+	applet->monitor = egg_dbus_monitor_new ();
+	g_signal_connect (applet->monitor, "connection-changed",
+			  G_CALLBACK (monitor_connection_cb), applet);
+	connection = dbus_g_bus_get (DBUS_BUS_SESSION, NULL);
+	egg_dbus_monitor_assign (applet->monitor, connection, GPM_DBUS_SERVICE);
 	gpm_brightness_applet_dbus_connect (applet);
 
 	/* coldplug */
