@@ -38,14 +38,16 @@
 #include <glib/gi18n.h>
 #include <dbus/dbus-glib.h>
 
-#include <libhal-gdevice.h>
-#include <libhal-gmanager.h>
-#include <libdbus-proxy.h>
+#include <hal-device.h>
+#include <hal-manager.h>
+#include "egg-dbus-proxy.h"
+
+#include "egg-debug.h"
+#include "egg-discrete.h"
 
 #include "gpm-brightness.h"
 #include "gpm-brightness-hal.h"
 #include "gpm-common.h"
-#include "egg-debug.h"
 #include "gpm-marshal.h"
 
 #define GPM_BRIGHTNESS_HAL_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), GPM_TYPE_BRIGHTNESS_HAL, GpmBrightnessHalPrivate))
@@ -57,7 +59,7 @@ struct GpmBrightnessHalPrivate
 	guint			 levels;
 	gchar			*udi;
 	gboolean		 hw_changed;
-	DbusProxy		*gproxy;
+	EggDbusProxy		*gproxy;
 
  	/* true if hardware automatically sets brightness in response to
  	 * key press events */
@@ -90,7 +92,7 @@ gpm_brightness_hal_get_hw (GpmBrightnessHal *brightness, guint *value_hw)
 
 	g_return_val_if_fail (GPM_IS_BRIGHTNESS_HAL (brightness), FALSE);
 
-	proxy = dbus_proxy_get_proxy (brightness->priv->gproxy);
+	proxy = egg_dbus_proxy_get_proxy (brightness->priv->gproxy);
 	if (proxy == NULL) {
 		egg_warning ("not connected to HAL");
 		return FALSE;
@@ -138,7 +140,7 @@ gpm_brightness_hal_set_hw (GpmBrightnessHal *brightness, guint value_hw)
 
 	g_return_val_if_fail (GPM_IS_BRIGHTNESS_HAL (brightness), FALSE);
 
-	proxy = dbus_proxy_get_proxy (brightness->priv->gproxy);
+	proxy = egg_dbus_proxy_get_proxy (brightness->priv->gproxy);
 	if (proxy == NULL) {
 		egg_warning ("not connected to HAL");
 		return FALSE;
@@ -265,7 +267,7 @@ gpm_brightness_hal_set (GpmBrightnessHal *brightness, guint percentage, gboolean
 	/* reset to not-changed */
 	brightness->priv->hw_changed = FALSE;
 
-	level_hw = gpm_percent_to_discrete (percentage, brightness->priv->levels);
+	level_hw = egg_discrete_from_percent (percentage, brightness->priv->levels);
 	brightness->priv->level_std_hw = level_hw;
 
 	/* update */
@@ -289,7 +291,7 @@ gpm_brightness_hal_get (GpmBrightnessHal *brightness, guint *percentage)
 {
 	g_return_val_if_fail (GPM_IS_BRIGHTNESS_HAL (brightness), FALSE);
 
-	*percentage = gpm_discrete_to_percent (brightness->priv->last_set_hw,
+	*percentage = egg_discrete_to_percent (brightness->priv->last_set_hw,
 					       brightness->priv->levels);
 	return TRUE;
 }
@@ -444,17 +446,18 @@ static void
 gpm_brightness_hal_init (GpmBrightnessHal *brightness)
 {
 	gchar **names;
-	HalGManager *manager;
-	HalGDevice *device;
+	HalManager *manager;
+	HalDevice *device;
 	gboolean res;
+	DBusGConnection *connection;
 
 	brightness->priv = GPM_BRIGHTNESS_HAL_GET_PRIVATE (brightness);
 	brightness->priv->gproxy = NULL;
 	brightness->priv->hw_changed = FALSE;
 
 	/* save udi of lcd adapter */
-	manager = hal_gmanager_new ();
-	hal_gmanager_find_capability (manager, "laptop_panel", &names, NULL);
+	manager = hal_manager_new ();
+	hal_manager_find_capability (manager, "laptop_panel", &names, NULL);
 	g_object_unref (manager);
 	if (names == NULL || names[0] == NULL) {
 		egg_warning ("No devices of capability laptop_panel");
@@ -463,13 +466,13 @@ gpm_brightness_hal_init (GpmBrightnessHal *brightness)
 
 	/* We only want first laptop_panel object (should only be one) */
 	brightness->priv->udi = g_strdup (names[0]);
-	hal_gmanager_free_capability (names);
+	hal_manager_free_capability (names);
 
-	device = hal_gdevice_new ();
-	hal_gdevice_set_udi (device, brightness->priv->udi);
+	device = hal_device_new ();
+	hal_device_set_udi (device, brightness->priv->udi);
 
 	/* get levels that the adapter supports -- this does not change ever */
-	hal_gdevice_get_uint (device, "laptop_panel.num_levels",
+	hal_device_get_uint (device, "laptop_panel.num_levels",
 			      &brightness->priv->levels, NULL);
 	egg_debug ("Laptop panel levels: %i", brightness->priv->levels);
 	if (brightness->priv->levels == 0 || brightness->priv->levels > 256) {
@@ -477,7 +480,7 @@ gpm_brightness_hal_init (GpmBrightnessHal *brightness)
 	}
 
 	/* Check if hardware handles brightness changes automatically */
-	res = hal_gdevice_get_bool (device, 
+	res = hal_device_get_bool (device, 
 				    "laptop_panel.brightness_in_hardware",
 			            &brightness->priv->does_own_updates, NULL);
 
@@ -496,9 +499,10 @@ gpm_brightness_hal_init (GpmBrightnessHal *brightness)
 	g_object_unref (device);
 
 	/* get a managed proxy */
-	brightness->priv->gproxy = dbus_proxy_new ();
-	dbus_proxy_assign (brightness->priv->gproxy, DBUS_PROXY_SYSTEM, HAL_DBUS_SERVICE,
-			   brightness->priv->udi, HAL_DBUS_INTERFACE_LAPTOP_PANEL);
+	brightness->priv->gproxy = egg_dbus_proxy_new ();
+	connection = dbus_g_bus_get (DBUS_BUS_SYSTEM, NULL);
+	egg_dbus_proxy_assign (brightness->priv->gproxy, connection, HAL_DBUS_SERVICE,
+			       brightness->priv->udi, HAL_DBUS_INTERFACE_LAPTOP_PANEL);
 
 	/* this changes under our feet */
 	gpm_brightness_hal_get_hw (brightness, &brightness->priv->last_set_hw);
