@@ -30,9 +30,9 @@
 #include <gtk/gtk.h>
 #include <X11/XF86keysym.h>
 
-#include <libhal-gmanager.h>
-#include <libhal-gdevice.h>
-#include <libhal-gdevicestore.h>
+#include <hal-manager.h>
+#include <hal-device.h>
+#include <hal-device-store.h>
 
 #include "gpm-common.h"
 #include "gpm-button.h"
@@ -49,10 +49,12 @@ struct GpmButtonPrivate
 {
 	GdkScreen		*screen;
 	GdkWindow		*window;
-	GHashTable		*hash_to_hal;
+	GHashTable		*keysym_to_name_hash;
+	gchar			*last_button;
+	GTimer			*timer;
 	gboolean		 lid_is_closed;
-	HalGManager		*hal_manager; /* remove when input events is in the kernel */
-	HalGDevicestore		*hal_devicestore;
+	HalManager		*hal_manager; /* remove when input events is in the kernel */
+	HalDeviceStore		*hal_device_store;
 };
 
 enum {
@@ -65,26 +67,54 @@ static gpointer gpm_button_object = NULL;
 
 G_DEFINE_TYPE (GpmButton, gpm_button, G_TYPE_OBJECT)
 
+#define GPM_BUTTON_DUPLICATE_TIMEOUT	0.25f
+
+/**
+ * gpm_button_emit_type:
+ **/
+gboolean
+gpm_button_emit_type (GpmButton *button, const gchar *type)
+{
+	g_return_val_if_fail (GPM_IS_BUTTON (button), FALSE);
+
+	/* did we just have this button before the timeout? */
+	if (g_strcmp0 (type, button->priv->last_button) == 0 &&
+	    g_timer_elapsed (button->priv->timer, NULL) < GPM_BUTTON_DUPLICATE_TIMEOUT) {
+		egg_debug ("ignoring duplicate button %s", type);
+		return FALSE;
+	}
+
+	egg_debug ("emitting button-pressed : %s", type);
+	g_signal_emit (button, signals [BUTTON_PRESSED], 0, type);
+
+	/* save type and last size */
+	g_free (button->priv->last_button);
+	button->priv->last_button = g_strdup (type);
+	g_timer_reset (button->priv->timer);
+
+	return TRUE;
+}
+
+/**
+ * gpm_button_filter_x_events:
+ **/
 static GdkFilterReturn
-gpm_button_filter_x_events (GdkXEvent *xevent,
-			    GdkEvent  *event,
-			    gpointer   data)
+gpm_button_filter_x_events (GdkXEvent *xevent, GdkEvent *event, gpointer data)
 {
 	GpmButton *button = (GpmButton *) data;
 	XEvent *xev = (XEvent *) xevent;
 	guint keycode;
-	gchar *key;
+	const gchar *key;
 	gchar *keycode_str;
 
-	if (xev->type != KeyPress) {
+	if (xev->type != KeyPress)
 		return GDK_FILTER_CONTINUE;
-	}
 
 	keycode = xev->xkey.keycode;
 
 	/* is the key string already in our DB? */
 	keycode_str = g_strdup_printf ("0x%x", keycode);
-	key = g_hash_table_lookup (button->priv->hash_to_hal, (gpointer) keycode_str);
+	key = g_hash_table_lookup (button->priv->keysym_to_name_hash, (gpointer) keycode_str);
 	g_free (keycode_str);
 
 	/* found anything? */
@@ -94,8 +124,8 @@ gpm_button_filter_x_events (GdkXEvent *xevent,
 		return GDK_FILTER_CONTINUE;
 	}
 
-	egg_debug ("Key %i mapped to HAL key %s", keycode, key);
-	g_signal_emit (button, signals [BUTTON_PRESSED], 0, key);
+	egg_debug ("Key %i mapped to key %s", keycode, key);
+	gpm_button_emit_type (button, key);
 
 	return GDK_FILTER_REMOVE;
 }
@@ -182,7 +212,7 @@ gpm_button_xevent_key (GpmButton *button, guint keysym, const gchar *hal_key)
 
 	/* is the key string already in our DB? */
 	keycode_str = g_strdup_printf ("0x%x", keycode);
-	key = g_hash_table_lookup (button->priv->hash_to_hal, (gpointer) keycode_str);
+	key = g_hash_table_lookup (button->priv->keysym_to_name_hash, (gpointer) keycode_str);
 	if (key != NULL) {
 		egg_warning ("found in hash %i", keycode);
 		g_free (keycode_str);
@@ -198,7 +228,7 @@ gpm_button_xevent_key (GpmButton *button, guint keysym, const gchar *hal_key)
 	}
 
 	/* add to hash table */
-	g_hash_table_insert (button->priv->hash_to_hal, (gpointer) keycode_str, (gpointer) g_strdup (hal_key));
+	g_hash_table_insert (button->priv->keysym_to_name_hash, (gpointer) keycode_str, (gpointer) g_strdup (hal_key));
 
 	/* the key is freed in the hash function unref */
 	return TRUE;
@@ -220,8 +250,7 @@ gpm_button_class_init (GpmButtonClass *klass)
 			      G_TYPE_FROM_CLASS (object_class),
 			      G_SIGNAL_RUN_LAST,
 			      G_STRUCT_OFFSET (GpmButtonClass, button_pressed),
-			      NULL,
-			      NULL,
+			      NULL, NULL,
 			      gpm_marshal_VOID__STRING,
 			      G_TYPE_NONE, 1, G_TYPE_STRING);
 }
@@ -232,11 +261,24 @@ gpm_button_class_init (GpmButtonClass *klass)
 gboolean
 gpm_button_is_lid_closed (GpmButton *button)
 {
-	g_return_val_if_fail (button != NULL, FALSE);
 	g_return_val_if_fail (GPM_IS_BUTTON (button), FALSE);
 	return button->priv->lid_is_closed;
 }
 
+/**
+ * gpm_button_reset_time:
+ *
+ * We have to refresh the event time on resume to handle duplicate buttons
+ * properly when the time is significant when we suspend.
+ **/
+gboolean
+gpm_button_reset_time (GpmButton *button)
+{
+	g_return_val_if_fail (GPM_IS_BUTTON (button), FALSE);
+	g_timer_reset (button->priv->timer);
+	return TRUE;
+}
+
 /**
  * emit_button_pressed:
  *
@@ -254,25 +296,22 @@ gpm_button_is_lid_closed (GpmButton *button)
  *      button.type=""
  */
 static void
-emit_button_pressed (GpmButton   *button,
-		     HalGDevice  *device,
-		     const gchar *details)
+emit_button_pressed (GpmButton *button, HalDevice *device, const gchar *details)
 {
 	gchar *type = NULL;
 	gboolean state;
-	const char *atype;
+	const gchar *atype;
 
 	g_return_if_fail (device != NULL);
 	g_return_if_fail (details != NULL);
 
 	if (strcmp (details, "") == 0) {
-		/* no details about the event, so we get more info
-		   for type 1 buttons */
-		hal_gdevice_get_string (device, "button.type", &type, NULL);
+		/* no details about the event, so we get more info for type 1 buttons */
+		hal_device_get_string (device, "button.type", &type, NULL);
 		/* hal may no longer be there */
 		if (type == NULL) {
-			egg_warning ("cannot get button type for %s", hal_gdevice_get_udi (device));
-			return;
+			egg_warning ("cannot get button type for %s", hal_device_get_udi (device));
+			goto out;
 		}
 	} else {
 		type = g_strdup (details);
@@ -282,16 +321,14 @@ emit_button_pressed (GpmButton   *button,
 	/* Buttons without state should default to true. */
 	state = TRUE;
 	/* we need to get the button state for lid buttons */
-	if (strcmp (type, "lid") == 0) {
-		hal_gdevice_get_bool (device, "button.state.value", &state, NULL);
-	}
+	if (strcmp (type, "lid") == 0)
+		hal_device_get_bool (device, "button.state.value", &state, NULL);
 
 	/* abstact away that HAL has an extra parameter */
-	if (strcmp (type, GPM_BUTTON_LID_DEP) == 0 && state == FALSE) {
+	if (strcmp (type, GPM_BUTTON_LID_DEP) == 0 && state == FALSE)
 		atype = GPM_BUTTON_LID_OPEN;
-	} else if (strcmp (type, GPM_BUTTON_LID_DEP) == 0 && state) {
+	else if (strcmp (type, GPM_BUTTON_LID_DEP) == 0 && state)
 		atype = GPM_BUTTON_LID_CLOSED;
-	}
 
 	/* filter out duplicate lid events */
 	if (strcmp (atype, GPM_BUTTON_LID_CLOSED) == 0) {
@@ -309,17 +346,9 @@ emit_button_pressed (GpmButton   *button,
 		button->priv->lid_is_closed = FALSE;
 	}
 
-	/* the names changed in 0.5.8 */
-	if (strcmp (type, GPM_BUTTON_BRIGHT_UP_DEP) == 0) {
-		atype = GPM_BUTTON_BRIGHT_UP;
-	} else if (strcmp (type, GPM_BUTTON_BRIGHT_DOWN_DEP) == 0) {
-		atype = GPM_BUTTON_BRIGHT_DOWN;
-	}
-
-	/* we now emit all buttons, even the ones we don't know */
-	egg_debug ("emitting button-pressed : %s", atype);
-	g_signal_emit (button, signals [BUTTON_PRESSED], 0, atype);
-
+	/* we emit all buttons, even the ones we don't know */
+	gpm_button_emit_type (button, atype);
+out:
 	g_free (type);
 }
 
@@ -335,7 +364,7 @@ emit_button_pressed (GpmButton   *button,
  * changed, and we have we have subscribed to changes for that device.
  */
 static void
-hal_device_property_modified_cb (HalGDevice    *device,
+hal_device_property_modified_cb (HalDevice    *device,
 				 const gchar   *key,
 				 gboolean       is_added,
 				 gboolean       is_removed,
@@ -346,13 +375,12 @@ hal_device_property_modified_cb (HalGDevice    *device,
 		   key, is_added, is_removed, finally);
 
 	/* do not process keys that have been removed */
-	if (is_removed) {
+	if (is_removed)
 		return;
-	}
 
 	/* only match button* values */
 	if (strncmp (key, "button", 6) == 0) {
-		egg_debug ("state of a button has changed : %s, %s", hal_gdevice_get_udi (device), key);
+		egg_debug ("state of a button has changed : %s, %s", hal_device_get_udi (device), key);
 		emit_button_pressed (button, device, "");
 	}
 }
@@ -368,16 +396,15 @@ hal_device_property_modified_cb (HalGDevice    *device,
  * changed, and we have we have subscribed to changes for that device.
  */
 static void
-hal_device_condition_cb (HalGDevice    *device,
+hal_device_condition_cb (HalDevice    *device,
 			 const gchar   *condition,
 			 const gchar   *details,
 			 GpmButton     *button)
 {
 	egg_debug ("condition=%s, details=%s", condition, details);
 
-	if (strcmp (condition, "ButtonPressed") == 0) {
+	if (strcmp (condition, "ButtonPressed") == 0)
 		emit_button_pressed (button, device, details);
-	}
 }
 
 /**
@@ -389,20 +416,20 @@ static void
 watch_add_button (GpmButton *button,
 		  const gchar   *udi)
 {
-	HalGDevice *device;
+	HalDevice *device;
 
-	device = hal_gdevice_new ();
-	hal_gdevice_set_udi (device, udi);
-	hal_gdevice_watch_condition (device);
-	hal_gdevice_watch_property_modified (device);
+	device = hal_device_new ();
+	hal_device_set_udi (device, udi);
+	hal_device_watch_condition (device);
+	hal_device_watch_property_modified (device);
 
 	g_signal_connect (device, "property-modified",
 			  G_CALLBACK (hal_device_property_modified_cb), button);
 	g_signal_connect (device, "device-condition",
 			  G_CALLBACK (hal_device_condition_cb), button);
 
-	/* when added to the devicestore, devices are automatically unref'ed */
-	hal_gdevicestore_insert (button->priv->hal_devicestore, device);
+	/* when added to the device_store, devices are automatically unref'ed */
+	hal_device_store_insert (button->priv->hal_device_store, device);
 }
 
 /**
@@ -418,7 +445,7 @@ coldplug_buttons (GpmButton *button)
 
 	/* devices of type button */
 	error = NULL;
-	ret = hal_gmanager_find_capability (button->priv->hal_manager, "button", &device_names, &error);
+	ret = hal_manager_find_capability (button->priv->hal_manager, "button", &device_names, &error);
 	if (!ret) {
 		egg_warning ("Couldn't obtain list of buttons: %s", error->message);
 		g_error_free (error);
@@ -434,19 +461,19 @@ coldplug_buttons (GpmButton *button)
 		egg_debug ("Couldn't obtain list of buttons");
 	}
 
-	hal_gmanager_free_capability (device_names);
+	hal_manager_free_capability (device_names);
 }
 
 /**
  * hal_daemon_start_cb:
  **/
 static void
-hal_daemon_start_cb (HalGManager *hal_manager,
+hal_daemon_start_cb (HalManager *hal_manager,
 		     GpmButton   *button)
 {
 	/* get new devices, hal has come back up */
-	if (button->priv->hal_devicestore == NULL) {
-		button->priv->hal_devicestore = hal_gdevicestore_new ();
+	if (button->priv->hal_device_store == NULL) {
+		button->priv->hal_device_store = hal_device_store_new ();
 		coldplug_buttons (button);
 	}
 }
@@ -455,13 +482,13 @@ hal_daemon_start_cb (HalGManager *hal_manager,
  * hal_daemon_stop_cb:
  **/
 static void
-hal_daemon_stop_cb (HalGManager *hal_manager,
+hal_daemon_stop_cb (HalManager *hal_manager,
 		    GpmButton   *button)
 {
 	/* clear devices, HAL is going down */
-	if (button->priv->hal_devicestore != NULL) {
-		g_object_unref (button->priv->hal_devicestore);
-		button->priv->hal_devicestore = NULL;
+	if (button->priv->hal_device_store != NULL) {
+		g_object_unref (button->priv->hal_device_store);
+		button->priv->hal_device_store = NULL;
 	}
 }
 
@@ -479,7 +506,9 @@ gpm_button_init (GpmButton *button)
 	button->priv->screen = gdk_screen_get_default ();
 	button->priv->window = gdk_screen_get_root_window (button->priv->screen);
 
-	button->priv->hash_to_hal = g_hash_table_new_full (g_str_hash, g_str_equal, g_free, g_free);
+	button->priv->keysym_to_name_hash = g_hash_table_new_full (g_str_hash, g_str_equal, g_free, g_free);
+	button->priv->last_button = NULL;
+	button->priv->timer = g_timer_new ();
 
 	button->priv->lid_is_closed = FALSE;
 
@@ -489,15 +518,20 @@ gpm_button_init (GpmButton *button)
 
 	if (have_xevents) {
 		/* register the brightness keys */
-//		gpm_button_xevent_key (button, XF86XK_Execute, GPM_BUTTON_POWER);
 		gpm_button_xevent_key (button, XF86XK_PowerOff, GPM_BUTTON_POWER);
-//		gpm_button_xevent_key (button, XF86XK_Suspend, GPM_BUTTON_SUSPEND);
+#ifdef HAVE_XF86XK_SUSPEND
+		gpm_button_xevent_key (button, XF86XK_Suspend, GPM_BUTTON_SUSPEND);
+#endif
 		gpm_button_xevent_key (button, XF86XK_Sleep, GPM_BUTTON_SUSPEND); /* should be configurable */
-//		gpm_button_xevent_key (button, XF86XK_Hibernate, GPM_BUTTON_HIBERNATE);
+#ifdef HAVE_XF86XK_HIBERNATE
+		gpm_button_xevent_key (button, XF86XK_Hibernate, GPM_BUTTON_HIBERNATE);
+#endif
 		gpm_button_xevent_key (button, XF86XK_MonBrightnessUp, GPM_BUTTON_BRIGHT_UP);
 		gpm_button_xevent_key (button, XF86XK_MonBrightnessDown, GPM_BUTTON_BRIGHT_DOWN);
 		gpm_button_xevent_key (button, XF86XK_ScreenSaver, GPM_BUTTON_LOCK);
-//		gpm_button_xevent_key (button, XF86XK_Battery, GPM_BUTTON_BATTERY);
+#ifdef HAVE_XF86XK_BATTERY
+		gpm_button_xevent_key (button, XF86XK_Battery, GPM_BUTTON_BATTERY);
+#endif
 		gpm_button_xevent_key (button, XF86XK_KbdBrightnessUp, GPM_BUTTON_KBD_BRIGHT_UP);
 		gpm_button_xevent_key (button, XF86XK_KbdBrightnessDown, GPM_BUTTON_KBD_BRIGHT_DOWN);
 		gpm_button_xevent_key (button, XF86XK_KbdLightOnOff, GPM_BUTTON_KBD_BRIGHT_TOGGLE);
@@ -508,13 +542,13 @@ gpm_button_init (GpmButton *button)
 	}
 
 	/* remove when button support is out of HAL */
-	button->priv->hal_manager = hal_gmanager_new ();
+	button->priv->hal_manager = hal_manager_new ();
 	g_signal_connect (button->priv->hal_manager, "daemon-start",
 			  G_CALLBACK (hal_daemon_start_cb), button);
 	g_signal_connect (button->priv->hal_manager, "daemon-stop",
 			  G_CALLBACK (hal_daemon_stop_cb), button);
 
-	button->priv->hal_devicestore = hal_gdevicestore_new ();
+	button->priv->hal_device_store = hal_device_store_new ();
 
 	coldplug_buttons (button);
 }
@@ -534,9 +568,11 @@ gpm_button_finalize (GObject *object)
 	button->priv = GPM_BUTTON_GET_PRIVATE (button);
 
 	g_object_unref (button->priv->hal_manager);
-	g_object_unref (button->priv->hal_devicestore);
+	g_object_unref (button->priv->hal_device_store);
+	g_free (button->priv->last_button);
+	g_timer_destroy (button->priv->timer);
 
-	g_hash_table_unref (button->priv->hash_to_hal);
+	g_hash_table_unref (button->priv->keysym_to_name_hash);
 
 	G_OBJECT_CLASS (gpm_button_parent_class)->finalize (object);
 }
