@@ -26,11 +26,11 @@
 #include <dbus/dbus-glib-lowlevel.h>
 #include <glib/gi18n.h>
 #include <string.h>
-#include <libdbus-monitor-session.h>
+#include <gconf/gconf-client.h>
 
-#include "gpm-inhibit.h"
 #include "egg-debug.h"
-#include "gpm-conf.h"
+#include "gpm-common.h"
+#include "gpm-inhibit.h"
 
 static void     gpm_inhibit_class_init (GpmInhibitClass *klass);
 static void     gpm_inhibit_init       (GpmInhibit      *inhibit);
@@ -49,8 +49,8 @@ typedef struct
 struct GpmInhibitPrivate
 {
 	GSList			*list;
-	DbusMonitorSession	*dbus_monitor;
-	GpmConf			*conf;
+	DBusGProxy		*proxy;
+	GConfClient			*conf;
 	gboolean		 ignore_inhibits;
 };
 
@@ -115,9 +115,8 @@ gpm_inhibit_find_cookie (GpmInhibit *inhibit, guint32 cookie)
 	/* search list */
 	ret = g_slist_find_custom (inhibit->priv->list, &cookie,
 				   gpm_inhibit_cookie_compare_func);
-	if (ret == NULL) {
+	if (ret == NULL)
 		return NULL;
-	}
 	data = (GpmInhibitData *) ret->data;
 	return data;
 }
@@ -169,9 +168,7 @@ gpm_inhibit_inhibit (GpmInhibit  *inhibit,
 	connection = dbus_g_method_get_sender (context);
 
 	/* handle where the application does not add required data */
-	if (connection == NULL ||
-	    application == NULL ||
-	    reason == NULL) {
+	if (connection == NULL || application == NULL || reason == NULL) {
 		egg_warning ("Recieved Inhibit, but application "
 			     "did not set the parameters correctly");
 		dbus_g_method_return (context, -1);
@@ -191,9 +188,8 @@ gpm_inhibit_inhibit (GpmInhibit  *inhibit,
 		   data->application, data->connection, data->reason, data->cookie);
 
 	/* only emit event on the first one */
-	if (g_slist_length (inhibit->priv->list) == 1) {
+	if (g_slist_length (inhibit->priv->list) == 1)
 		g_signal_emit (inhibit, signals [HAS_INHIBIT_CHANGED], 0, TRUE);
-	}
 
 	dbus_g_method_return (context, data->cookie);
 }
@@ -238,9 +234,8 @@ gpm_inhibit_un_inhibit (GpmInhibit  *inhibit,
 	inhibit->priv->list = g_slist_remove (inhibit->priv->list, (gconstpointer) data);
 
 	/* only emit event on the last one */
-	if (g_slist_length (inhibit->priv->list) == 0) {
+	if (g_slist_length (inhibit->priv->list) == 0)
 		g_signal_emit (inhibit, signals [HAS_INHIBIT_CHANGED], 0, FALSE);
-	}
 
 	return TRUE;
 }
@@ -289,25 +284,15 @@ gpm_inhibit_remove_dbus (GpmInhibit  *inhibit,
 }
 
 /**
- * dbus_noc_session_cb:
- * @power: The power class instance
- * @name: The DBUS name, e.g. hal.freedesktop.org
- * @prev: The previous name, e.g. :0.13
- * @new: The new name, e.g. :0.14
- * @inhibit: This inhibit class instance
- *
- * The noc session DBUS callback.
+ * gpm_inhibit_name_owner_changed_cb:
  **/
 static void
-dbus_noc_session_cb (DbusMonitorSession *dbus_monitor,
-		     const gchar    *name,
-		     const gchar    *prev,
-		     const gchar    *new,
-		     GpmInhibit	    *inhibit)
+gpm_inhibit_name_owner_changed_cb (DBusGProxy *proxy, const gchar *name,
+				   const gchar *prev, const gchar *new,
+				   GpmInhibit *inhibit)
 {
-	if (strlen (new) == 0) {
+	if (strlen (new) == 0)
 		gpm_inhibit_remove_dbus (inhibit, name);
-	}
 }
 
 /**
@@ -356,9 +341,7 @@ gpm_inhibit_has_inhibit (GpmInhibit *inhibit,
  *
  **/
 void
-gpm_inhibit_get_message (GpmInhibit  *inhibit,
-			 GString     *message,
-			 const gchar *action)
+gpm_inhibit_get_message (GpmInhibit *inhibit, GString *message, const gchar *action)
 {
 	guint a;
 	GpmInhibitData *data;
@@ -432,19 +415,21 @@ gpm_inhibit_get_message (GpmInhibit  *inhibit,
 }
 
 /**
- * conf_key_changed_cb:
+ * gpm_conf_gconf_key_changed_cb:
  *
  * We might have to do things when the gconf keys change; do them here.
  **/
 static void
-conf_key_changed_cb (GpmConf       *conf,
-		     const gchar   *key,
-		     GpmInhibit    *inhibit)
+gpm_conf_gconf_key_changed_cb (GConfClient *client, guint cnxn_id, GConfEntry *entry, GpmInhibit *inhibit)
 {
-	if (strcmp (key, GPM_CONF_IGNORE_INHIBITS) == 0) {
-		gpm_conf_get_bool (inhibit->priv->conf, GPM_CONF_IGNORE_INHIBITS,
-				   &inhibit->priv->ignore_inhibits);
-	}
+	GConfValue *value;
+
+	value = gconf_entry_get_value (entry);
+	if (value == NULL)
+		return;
+
+	if (strcmp (entry->key, GPM_CONF_IGNORE_INHIBITS) == 0)
+		inhibit->priv->ignore_inhibits = gconf_value_get_bool (value);
 }
 
 /** intialise the class */
@@ -467,18 +452,36 @@ gpm_inhibit_class_init (GpmInhibitClass *klass)
 static void
 gpm_inhibit_init (GpmInhibit *inhibit)
 {
+	DBusGConnection *connection;
+	GError *error = NULL;
+
 	inhibit->priv = GPM_INHIBIT_GET_PRIVATE (inhibit);
 	inhibit->priv->list = NULL;
-	inhibit->priv->dbus_monitor = dbus_monitor_session_new ();
-	g_signal_connect (inhibit->priv->dbus_monitor, "name-owner-changed",
-			  G_CALLBACK (dbus_noc_session_cb), inhibit);
+	inhibit->priv->conf = gconf_client_get_default ();
 
-	inhibit->priv->conf = gpm_conf_new ();
-	g_signal_connect (inhibit->priv->conf, "value-changed",
-			  G_CALLBACK (conf_key_changed_cb), inhibit);
+	/* watch gnome-power-manager keys */
+	gconf_client_add_dir (inhibit->priv->conf, GPM_CONF_DIR,
+			      GCONF_CLIENT_PRELOAD_NONE, NULL);
+	gconf_client_notify_add (inhibit->priv->conf, GPM_CONF_DIR,
+				 (GConfClientNotifyFunc) gpm_conf_gconf_key_changed_cb,
+				 inhibit, NULL, NULL);
+
+	connection = dbus_g_bus_get (DBUS_BUS_SESSION, &error);
+	if (error != NULL) {
+		egg_warning ("Cannot connect to bus: %s", error->message);
+		g_error_free (error);
+	}
+	inhibit->priv->proxy = dbus_g_proxy_new_for_name_owner (connection,
+								DBUS_SERVICE_DBUS, DBUS_PATH_DBUS,
+						 		DBUS_INTERFACE_DBUS, NULL);
+	dbus_g_proxy_add_signal (inhibit->priv->proxy, "NameOwnerChanged",
+				 G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_INVALID);
+	dbus_g_proxy_connect_signal (inhibit->priv->proxy, "NameOwnerChanged",
+				     G_CALLBACK (gpm_inhibit_name_owner_changed_cb),
+				     inhibit, NULL);
 
 	/* Do we ignore inhibit requests? */
-	gpm_conf_get_bool (inhibit->priv->conf, GPM_CONF_IGNORE_INHIBITS, &inhibit->priv->ignore_inhibits);
+	inhibit->priv->ignore_inhibits = gconf_client_get_bool (inhibit->priv->conf, GPM_CONF_IGNORE_INHIBITS, NULL);
 }
 
 /** finalise the object */
@@ -502,7 +505,7 @@ gpm_inhibit_finalize (GObject *object)
 	g_slist_free (inhibit->priv->list);
 
 	g_object_unref (inhibit->priv->conf);
-	g_object_unref (inhibit->priv->dbus_monitor);
+	g_object_unref (inhibit->priv->proxy);
 	G_OBJECT_CLASS (gpm_inhibit_parent_class)->finalize (object);
 }
 
@@ -518,14 +521,14 @@ gpm_inhibit_new (void)
 /***************************************************************************
  ***                          MAKE CHECK TESTS                           ***
  ***************************************************************************/
-#ifdef GPM_BUILD_TESTS
-#include "gpm-self-test.h"
-#include <libdbus-proxy.h>
+#ifdef EGG_TEST
+#include "egg-test.h"
+#include "egg-dbus-proxy.h"
 #include "gpm-common.h"
 
 /** cookie is returned as an unsigned integer */
 static gboolean
-inhibit (DbusProxy       *gproxy,
+inhibit (EggDbusProxy       *gproxy,
 	 const gchar     *appname,
 	 const gchar     *reason,
 	 guint           *cookie)
@@ -536,7 +539,7 @@ inhibit (DbusProxy       *gproxy,
 
 	g_return_val_if_fail (cookie != NULL, FALSE);
 
-	proxy = dbus_proxy_get_proxy (gproxy);
+	proxy = egg_dbus_proxy_get_proxy (gproxy);
 	if (proxy == NULL) {
 		g_warning ("not connected");
 		return FALSE;
@@ -562,14 +565,14 @@ inhibit (DbusProxy       *gproxy,
 }
 
 static gboolean
-uninhibit (DbusProxy *gproxy,
+uninhibit (EggDbusProxy *gproxy,
 	   guint      cookie)
 {
 	GError *error = NULL;
 	gboolean ret;
 	DBusGProxy *proxy;
 
-	proxy = dbus_proxy_get_proxy (gproxy);
+	proxy = egg_dbus_proxy_get_proxy (gproxy);
 	if (proxy == NULL) {
 		g_warning ("not connected");
 		return FALSE;
@@ -587,14 +590,14 @@ uninhibit (DbusProxy *gproxy,
 }
 
 static gboolean
-has_inhibit (DbusProxy *gproxy,
+has_inhibit (EggDbusProxy *gproxy,
 			      gboolean        *has_inhibit)
 {
 	GError  *error = NULL;
 	gboolean ret;
 	DBusGProxy *proxy;
 
-	proxy = dbus_proxy_get_proxy (gproxy);
+	proxy = egg_dbus_proxy_get_proxy (gproxy);
 	if (proxy == NULL) {
 		g_warning ("not connected");
 		return FALSE;
@@ -617,23 +620,23 @@ has_inhibit (DbusProxy *gproxy,
 }
 
 void
-gpm_st_inhibit (GpmSelfTest *test)
+gpm_inhibit_test (EggTest *test)
 {
 	gboolean ret;
 	gboolean valid;
 	guint cookie1 = 0;
 	guint cookie2 = 0;
-	DbusProxy *gproxy;
+	DBusGConnection *connection;
+	EggDbusProxy *gproxy;
 
-	if (gpm_st_start (test, "GpmInhibit") == FALSE) {
+	if (egg_test_start (test, "GpmInhibit") == FALSE) {
 		return;
 	}
 
-	gproxy = dbus_proxy_new ();
-	dbus_proxy_assign (gproxy, DBUS_PROXY_SESSION,
-				   GPM_DBUS_SERVICE,
-				   GPM_DBUS_PATH_INHIBIT,
-				   GPM_DBUS_INTERFACE_INHIBIT);
+	gproxy = egg_dbus_proxy_new ();
+	connection = dbus_g_bus_get (DBUS_BUS_SESSION, NULL);
+	egg_dbus_proxy_assign (gproxy, connection, GPM_DBUS_SERVICE,
+			       GPM_DBUS_PATH_INHIBIT, GPM_DBUS_INTERFACE_INHIBIT);
 
 	if (gproxy == NULL) {
 		g_warning ("Unable to get connection to power manager");
@@ -641,96 +644,96 @@ gpm_st_inhibit (GpmSelfTest *test)
 	}
 
 	/************************************************************/
-	gpm_st_title (test, "make sure we are not inhibited");
+	egg_test_title (test, "make sure we are not inhibited");
 	ret = has_inhibit (gproxy, &valid);
 	if (!ret) {
-		gpm_st_failed (test, "Unable to test validity");
+		egg_test_failed (test, "Unable to test validity");
 	} else if (valid) {
-		gpm_st_failed (test, "Already inhibited");
+		egg_test_failed (test, "Already inhibited");
 	} else {
-		gpm_st_success (test, NULL);
+		egg_test_success (test, NULL);
 	}
 
 	/************************************************************/
-	gpm_st_title (test, "clear an invalid cookie");
+	egg_test_title (test, "clear an invalid cookie");
 	ret = uninhibit (gproxy, 123456);
 	if (!ret) {
-		gpm_st_success (test, "invalid cookie failed as expected");
+		egg_test_success (test, "invalid cookie failed as expected");
 	} else {
-		gpm_st_failed (test, "should have rejected invalid cookie");
+		egg_test_failed (test, "should have rejected invalid cookie");
 	}
 
 	/************************************************************/
-	gpm_st_title (test, "get auto cookie 1");
+	egg_test_title (test, "get auto cookie 1");
 	ret = inhibit (gproxy,
 				  "gnome-power-self-test",
 				  "test inhibit",
 				  &cookie1);
 	if (!ret) {
-		gpm_st_failed (test, "Unable to inhibit");
+		egg_test_failed (test, "Unable to inhibit");
 	} else if (cookie1 == 0) {
-		gpm_st_failed (test, "Cookie invalid (cookie: %u)", cookie1);
+		egg_test_failed (test, "Cookie invalid (cookie: %u)", cookie1);
 	} else {
-		gpm_st_success (test, "cookie: %u", cookie1);
+		egg_test_success (test, "cookie: %u", cookie1);
 	}
 
 	/************************************************************/
-	gpm_st_title (test, "make sure we are auto inhibited");
+	egg_test_title (test, "make sure we are auto inhibited");
 	ret = has_inhibit (gproxy, &valid);
 	if (!ret) {
-		gpm_st_failed (test, "Unable to test validity");
+		egg_test_failed (test, "Unable to test validity");
 	} else if (valid) {
-		gpm_st_success (test, "inhibited");
+		egg_test_success (test, "inhibited");
 	} else {
-		gpm_st_failed (test, "inhibit failed");
+		egg_test_failed (test, "inhibit failed");
 	}
 
 	/************************************************************/
-	gpm_st_title (test, "get cookie 2");
+	egg_test_title (test, "get cookie 2");
 	ret = inhibit (gproxy,
 				  "gnome-power-self-test",
 				  "test inhibit",
 				  &cookie2);
 	if (!ret) {
-		gpm_st_failed (test, "Unable to inhibit");
+		egg_test_failed (test, "Unable to inhibit");
 	} else if (cookie2 == 0) {
-		gpm_st_failed (test, "Cookie invalid (cookie: %u)", cookie2);
+		egg_test_failed (test, "Cookie invalid (cookie: %u)", cookie2);
 	} else {
-		gpm_st_success (test, "cookie: %u", cookie2);
+		egg_test_success (test, "cookie: %u", cookie2);
 	}
 
 	/************************************************************/
-	gpm_st_title (test, "clear cookie 1");
+	egg_test_title (test, "clear cookie 1");
 	ret = uninhibit (gproxy, cookie1);
 	if (!ret) {
-		gpm_st_failed (test, "cookie failed to clear");
+		egg_test_failed (test, "cookie failed to clear");
 	} else {
-		gpm_st_success (test, NULL);
+		egg_test_success (test, NULL);
 	}
 
 	/************************************************************/
-	gpm_st_title (test, "make sure we are still inhibited");
+	egg_test_title (test, "make sure we are still inhibited");
 	ret = has_inhibit (gproxy, &valid);
 	if (!ret) {
-		gpm_st_failed (test, "Unable to test validity");
+		egg_test_failed (test, "Unable to test validity");
 	} else if (valid) {
-		gpm_st_success (test, "inhibited");
+		egg_test_success (test, "inhibited");
 	} else {
-		gpm_st_failed (test, "inhibit failed");
+		egg_test_failed (test, "inhibit failed");
 	}
 
 	/************************************************************/
-	gpm_st_title (test, "clear cookie 2");
+	egg_test_title (test, "clear cookie 2");
 	ret = uninhibit (gproxy, cookie2);
 	if (!ret) {
-		gpm_st_failed (test, "cookie failed to clear");
+		egg_test_failed (test, "cookie failed to clear");
 	} else {
-		gpm_st_success (test, NULL);
+		egg_test_success (test, NULL);
 	}
 
 	g_object_unref (gproxy);
 
-	gpm_st_end (test);
+	egg_test_end (test);
 }
 
 #endif
