@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
  *
- * Copyright (C) 2007 Richard Hughes <richard@hughsie.com>
+ * Copyright (C) 2007-2008 Richard Hughes <richard@hughsie.com>
  *
  * Licensed under the GNU General Public License Version 2
  *
@@ -26,12 +26,12 @@
 #include <glib/gi18n.h>
 #include <dbus/dbus-glib.h>
 
-#include "gpm-conf.h"
+#include <gconf/gconf-client.h>
 #include "gpm-phone.h"
 #include "egg-debug.h"
 #include "gpm-marshal.h"
 
-#include <libdbus-watch.h>
+#include "egg-dbus-monitor.h"
 
 static void     gpm_phone_class_init (GpmPhoneClass *klass);
 static void     gpm_phone_init       (GpmPhone      *phone);
@@ -43,7 +43,7 @@ struct GpmPhonePrivate
 {
 	DBusGProxy		*proxy;
 	DBusGConnection		*connection;
-	DbusWatch		*watch;
+	EggDbusMonitor		*monitor;
 	gboolean		 present;
 	guint			 percentage;
 	gboolean		 onac;	 
@@ -53,7 +53,6 @@ enum {
 	DEVICE_ADDED,
 	DEVICE_REMOVED,
 	DEVICE_REFRESH,
-	CONNECTION_CHANGED,
 	LAST_SIGNAL
 };
 
@@ -216,9 +215,7 @@ gpm_phone_class_init (GpmPhoneClass *klass)
 			      G_TYPE_FROM_CLASS (object_class),
 			      G_SIGNAL_RUN_LAST,
 			      G_STRUCT_OFFSET (GpmPhoneClass, device_added),
-			      NULL,
-			      NULL,
-			      g_cclosure_marshal_VOID__UINT,
+			      NULL, NULL, g_cclosure_marshal_VOID__UINT,
 			      G_TYPE_NONE, 1, G_TYPE_UINT);
 
 	signals [DEVICE_REMOVED] =
@@ -226,9 +223,7 @@ gpm_phone_class_init (GpmPhoneClass *klass)
 			      G_TYPE_FROM_CLASS (object_class),
 			      G_SIGNAL_RUN_LAST,
 			      G_STRUCT_OFFSET (GpmPhoneClass, device_removed),
-			      NULL,
-			      NULL,
-			      g_cclosure_marshal_VOID__UINT,
+			      NULL, NULL, g_cclosure_marshal_VOID__UINT,
 			      G_TYPE_NONE, 1, G_TYPE_UINT);
 
 	signals [DEVICE_REFRESH] =
@@ -236,20 +231,8 @@ gpm_phone_class_init (GpmPhoneClass *klass)
 			      G_TYPE_FROM_CLASS (object_class),
 			      G_SIGNAL_RUN_LAST,
 			      G_STRUCT_OFFSET (GpmPhoneClass, device_refresh),
-			      NULL,
-			      NULL,
-			      g_cclosure_marshal_VOID__UINT,
+			      NULL, NULL, g_cclosure_marshal_VOID__UINT,
 			      G_TYPE_NONE, 1, G_TYPE_UINT);
-
-	signals [CONNECTION_CHANGED] =
-		g_signal_new ("connection-changed",
-			      G_TYPE_FROM_CLASS (object_class),
-			      G_SIGNAL_RUN_LAST,
-			      G_STRUCT_OFFSET (GpmPhoneClass, connection_changed),
-			      NULL,
-			      NULL,
-			      g_cclosure_marshal_VOID__BOOLEAN,
-			      G_TYPE_NONE, 1, G_TYPE_BOOLEAN);
 }
 
 /**
@@ -336,21 +319,20 @@ gpm_phone_dbus_disconnect (GpmPhone *phone)
 }
 
 /**
- * watch_connection_cb:
+ * monitor_connection_cb:
  * @proxy: The dbus raw proxy
  * @status: The status of the service, where TRUE is connected
  * @screensaver: This class instance
  **/
 static void
-watch_connection_cb (DbusWatch *watch,
+monitor_connection_cb (EggDbusMonitor *monitor,
 		     gboolean   status,
 		     GpmPhone  *phone)
 {
-	if (status) {
+	if (status)
 		gpm_phone_dbus_connect (phone);
-	} else {
+	else
 		gpm_phone_dbus_disconnect (phone);
-	}
 }
 
 /**
@@ -360,6 +342,7 @@ watch_connection_cb (DbusWatch *watch,
 static void
 gpm_phone_init (GpmPhone *phone)
 {
+	DBusGConnection *connection;
 	phone->priv = GPM_PHONE_GET_PRIVATE (phone);
 
 	phone->priv->connection = NULL;
@@ -368,10 +351,11 @@ gpm_phone_init (GpmPhone *phone)
 	phone->priv->percentage = 0;
 	phone->priv->onac = FALSE;
 
-	phone->priv->watch = dbus_watch_new ();
-	g_signal_connect (phone->priv->watch, "connection-changed",
-			  G_CALLBACK (watch_connection_cb), phone);
-	dbus_watch_assign (phone->priv->watch, DBUS_WATCH_SESSION, GNOME_PHONE_MANAGER_DBUS_SERVICE);
+	phone->priv->monitor = egg_dbus_monitor_new ();
+	g_signal_connect (phone->priv->monitor, "connection-changed",
+			  G_CALLBACK (monitor_connection_cb), phone);
+	connection = dbus_g_bus_get (DBUS_BUS_SESSION, NULL);
+	egg_dbus_monitor_assign (phone->priv->monitor, connection, GNOME_PHONE_MANAGER_DBUS_SERVICE);
 	gpm_phone_dbus_connect (phone);
 }
 
@@ -390,9 +374,8 @@ gpm_phone_finalize (GObject *object)
 	phone->priv = GPM_PHONE_GET_PRIVATE (phone);
 
 	gpm_phone_dbus_disconnect (phone);
-	if (phone->priv->watch != NULL) {
-		g_object_unref (phone->priv->watch);
-	}
+	if (phone->priv->monitor != NULL)
+		g_object_unref (phone->priv->monitor);
 
 	G_OBJECT_CLASS (gpm_phone_parent_class)->finalize (object);
 }
@@ -416,13 +399,13 @@ gpm_phone_new (void)
 /***************************************************************************
  ***                          MAKE CHECK TESTS                           ***
  ***************************************************************************/
-#ifdef GPM_BUILD_TESTS
-#include "gpm-self-test.h"
+#ifdef EGG_TEST
+#include "egg-test.h"
 
 static gboolean test_got_refresh = FALSE;
 
 static void
-gpm_st_mainloop_wait (guint ms)
+egg_test_mainloop_wait (guint ms)
 {
 	GMainLoop *loop;
 	loop = g_main_loop_new (NULL, FALSE);
@@ -436,101 +419,101 @@ phone_device_refresh_cb (GpmPhone     *phone,
 		         gpointer     *data)
 {
 	g_debug ("index refresh = %i", index);
-	if (index == 0 && GPOINTER_TO_UINT (data) == 44) {
+	if (index == 0 && GPOINTER_TO_UINT (data) == 44)
 		test_got_refresh = TRUE;
-	}
 }
 
 void
-gpm_st_phone (GpmSelfTest *test)
+gpm_phone_test (EggTest *test)
 {
 	GpmPhone *phone;
 	guint value;
 	gboolean ret;
 
-	if (gpm_st_start (test, "GpmPhone") == FALSE) {
+	if (egg_test_start (test, "GpmPhone") == FALSE) {
 		return;
 	}
 
 	/************************************************************/
-	gpm_st_title (test, "make sure we get a non null phone");
+	egg_test_title (test, "make sure we get a non null phone");
 	phone = gpm_phone_new ();
-	if (phone != NULL) {
-		gpm_st_success (test, "got GpmPhone");
-	} else {
-		gpm_st_failed (test, "could not get GpmPhone");
-	}
+	if (phone != NULL)
+		egg_test_success (test, "got GpmPhone");
+	else
+		egg_test_failed (test, "could not get GpmPhone");
 
 	/* connect signals */
 	g_signal_connect (phone, "device-refresh",
 			  G_CALLBACK (phone_device_refresh_cb), GUINT_TO_POINTER(44));
 
 	/************************************************************/
-	gpm_st_title (test, "make sure we got a connection");
+	egg_test_title (test, "make sure we got a connection");
 	if (phone->priv->proxy != NULL) {
-		gpm_st_success (test, "got connection");
+		egg_test_success (test, "got connection");
 	} else {
-		gpm_st_failed (test, "could not get a connection!");
+		/* skip this part of the test */
+		egg_test_success (test, "could not get a connection!");
+		goto out;
 	}
 
 	/************************************************************/
-	gpm_st_title (test, "coldplug the data");
+	egg_test_title (test, "coldplug the data");
 	ret = gpm_phone_coldplug (phone);
 	if (ret) {
-		gpm_st_success (test, "coldplug okay");
+		egg_test_success (test, "coldplug okay");
 	} else {
-		gpm_st_failed (test, "could not coldplug");
+		egg_test_failed (test, "could not coldplug");
 	}
 
-	gpm_st_mainloop_wait (500);
+	egg_test_mainloop_wait (500);
 
 	/************************************************************/
-	gpm_st_title (test, "got refresh");
+	egg_test_title (test, "got refresh");
 	if (test_got_refresh) {
-		gpm_st_success (test, NULL);
+		egg_test_success (test, NULL);
 	} else {
-		gpm_st_failed (test, "did not get refresh");
+		egg_test_failed (test, "did not get refresh");
 	}
 
 	/************************************************************/
-	gpm_st_title (test, "check the connected phones");
+	egg_test_title (test, "check the connected phones");
 	value = gpm_phone_get_num_batteries (phone);
 	if (value == 1) {
-		gpm_st_success (test, "connected phone");
+		egg_test_success (test, "connected phone");
 	} else {
-		gpm_st_failed (test, "not connected with %i (phone not connected?)", value);
+		egg_test_failed (test, "not connected with %i (phone not connected?)", value);
 	}
 
 	/************************************************************/
-	gpm_st_title (test, "check the present value");
+	egg_test_title (test, "check the present value");
 	ret = gpm_phone_get_present (phone, 0);
 	if (ret) {
-		gpm_st_success (test, "we are here!");
+		egg_test_success (test, "we are here!");
 	} else {
-		gpm_st_failed (test, "not here...");
+		egg_test_failed (test, "not here...");
 	}
 
 	/************************************************************/
-	gpm_st_title (test, "check the percentage");
+	egg_test_title (test, "check the percentage");
 	value = gpm_phone_get_percentage (phone, 0);
 	if (value != 0) {
-		gpm_st_success (test, "percentage is %i", phone->priv->percentage);
+		egg_test_success (test, "percentage is %i", phone->priv->percentage);
 	} else {
-		gpm_st_failed (test, "could not get value");
+		egg_test_failed (test, "could not get value");
 	}
 
 	/************************************************************/
-	gpm_st_title (test, "check the ac value");
+	egg_test_title (test, "check the ac value");
 	ret = gpm_phone_get_on_ac (phone, 0);
 	if (!ret) {
-		gpm_st_success (test, "not charging, correct");
+		egg_test_success (test, "not charging, correct");
 	} else {
-		gpm_st_failed (test, "charging?");
+		egg_test_failed (test, "charging?");
 	}
-
+out:
 	g_object_unref (phone);
 
-	gpm_st_end (test);
+	egg_test_end (test);
 }
 
 #endif
