@@ -25,11 +25,12 @@
 #include <glib.h>
 #include <glib/gi18n.h>
 #include <dbus/dbus-glib.h>
+#include <gconf/gconf-client.h>
 
-#include "gpm-conf.h"
 #include "gpm-screensaver.h"
-#include "gpm-debug.h"
-#include <libdbus-proxy.h>
+#include "gpm-common.h"
+#include "egg-debug.h"
+#include "egg-dbus-proxy.h"
 
 static void     gpm_screensaver_class_init (GpmScreensaverClass *klass);
 static void     gpm_screensaver_init       (GpmScreensaver      *screensaver);
@@ -39,8 +40,8 @@ static void     gpm_screensaver_finalize   (GObject		*object);
 
 struct GpmScreensaverPrivate
 {
-	DbusProxy		*gproxy;
-	GpmConf			*conf;
+	EggDbusProxy		*gproxy;
+	GConfClient		*conf;
 	guint			 idle_delay;	/* the setting in g-s-p, cached */
 };
 
@@ -53,7 +54,7 @@ enum {
 	LAST_SIGNAL
 };
 
-static guint signals [LAST_SIGNAL] = { 0, };
+static guint signals [LAST_SIGNAL] = { 0 };
 static gpointer gpm_screensaver_object = NULL;
 
 G_DEFINE_TYPE (GpmScreensaver, gpm_screensaver, G_TYPE_OBJECT)
@@ -65,7 +66,7 @@ static void
 gpm_screensaver_auth_begin (DBusGProxy     *proxy,
 			    GpmScreensaver *screensaver)
 {
-	gpm_debug ("emitting auth-request : (%i)", TRUE);
+	egg_debug ("emitting auth-request : (%i)", TRUE);
 	g_signal_emit (screensaver, signals [AUTH_REQUEST], 0, TRUE);
 }
 
@@ -76,7 +77,7 @@ static void
 gpm_screensaver_auth_end (DBusGProxy     *proxy,
 			  GpmScreensaver *screensaver)
 {
-	gpm_debug ("emitting auth-request : (%i)", FALSE);
+	egg_debug ("emitting auth-request : (%i)", FALSE);
 	g_signal_emit (screensaver, signals [AUTH_REQUEST], 0, FALSE);
 }
 
@@ -88,7 +89,7 @@ gpm_screensaver_session_idle_changed (DBusGProxy     *proxy,
 			      gboolean        is_idle,
 			      GpmScreensaver *screensaver)
 {
-	gpm_debug ("emitting session-idle-changed : (%i)", is_idle);
+	egg_debug ("emitting session-idle-changed : (%i)", is_idle);
 	g_signal_emit (screensaver, signals [SESSION_IDLE_CHANGED], 0, is_idle);
 }
 
@@ -99,7 +100,7 @@ gpm_screensaver_powersave_idle_changed (DBusGProxy     *proxy,
 			                gboolean        is_idle,
 			                GpmScreensaver *screensaver)
 {
-	gpm_debug ("emitting powersave-idle-changed : (%i)", is_idle);
+	egg_debug ("emitting powersave-idle-changed : (%i)", is_idle);
 	g_signal_emit (screensaver, signals [POWERSAVE_IDLE_CHANGED], 0, is_idle);
 }
 
@@ -114,9 +115,9 @@ gpm_screensaver_proxy_connect_more (GpmScreensaver *screensaver)
 
 	g_return_val_if_fail (GPM_IS_SCREENSAVER (screensaver), FALSE);
 
-	proxy = dbus_proxy_get_proxy (screensaver->priv->gproxy);
+	proxy = egg_dbus_proxy_get_proxy (screensaver->priv->gproxy);
 	if (proxy == NULL) {
-		gpm_warning ("not connected");
+		egg_warning ("not connected");
 		return FALSE;
 	}
 
@@ -163,26 +164,27 @@ gpm_screensaver_proxy_disconnect_more (GpmScreensaver *screensaver)
 	g_return_val_if_fail (GPM_IS_SCREENSAVER (screensaver), FALSE);
 
 	g_signal_emit (screensaver, signals [CONNECTION_CHANGED], 0, FALSE);
-	gpm_debug ("gnome-screensaver disconnected from the session DBUS");
+	egg_debug ("gnome-screensaver disconnected from the session DBUS");
 	return TRUE;
 }
 
 /**
- * gconf_key_changed_cb:
+ * gpm_conf_gconf_key_changed_cb:
  *
- * Turn a gconf key change into a signal
+ * We might have to do things when the gconf keys change; do them here.
  **/
 static void
-gconf_key_changed_cb (GpmConf        *conf,
-		      const gchar    *key,
-		      GpmScreensaver *screensaver)
+gpm_conf_gconf_key_changed_cb (GConfClient *client, guint cnxn_id, GConfEntry *entry, GpmScreensaver *screensaver)
 {
-	g_return_if_fail (GPM_IS_SCREENSAVER (screensaver));
-	gpm_debug ("key : %s", key);
+	GConfValue *value;
 
-	if (strcmp (key, GS_PREF_IDLE_DELAY) == 0) {
-		gpm_conf_get_uint (screensaver->priv->conf, key, &screensaver->priv->idle_delay);
-		gpm_debug ("emitting gs-delay-changed : %i", screensaver->priv->idle_delay);
+	value = gconf_entry_get_value (entry);
+	if (value == NULL)
+		return;
+
+	if (strcmp (entry->key, GS_PREF_IDLE_DELAY) == 0) {
+		screensaver->priv->idle_delay = gconf_value_get_int (value);
+		egg_debug ("emitting gs-delay-changed : %i", screensaver->priv->idle_delay);
 		g_signal_emit (screensaver, signals [GS_DELAY_CHANGED], 0, screensaver->priv->idle_delay);
 	}
 }
@@ -198,7 +200,7 @@ gpm_screensaver_lock_enabled (GpmScreensaver *screensaver)
 	gboolean enabled;
 	g_return_val_if_fail (GPM_IS_SCREENSAVER (screensaver), FALSE);
 
-	gpm_conf_get_bool (screensaver->priv->conf, GS_PREF_LOCK_ENABLED, &enabled);
+	enabled = gconf_client_get_bool (screensaver->priv->conf, GS_PREF_LOCK_ENABLED, NULL);
 
 	return enabled;
 }
@@ -212,7 +214,7 @@ gboolean
 gpm_screensaver_lock_set (GpmScreensaver *screensaver, gboolean lock)
 {
 	g_return_val_if_fail (GPM_IS_SCREENSAVER (screensaver), FALSE);
-	gpm_conf_set_bool (screensaver->priv->conf, GS_PREF_LOCK_ENABLED, lock);
+	gconf_client_set_bool (screensaver->priv->conf, GS_PREF_LOCK_ENABLED, lock, NULL);
 	return TRUE;
 }
 
@@ -241,13 +243,13 @@ gpm_screensaver_lock (GpmScreensaver *screensaver)
 
 	g_return_val_if_fail (GPM_IS_SCREENSAVER (screensaver), FALSE);
 
-	proxy = dbus_proxy_get_proxy (screensaver->priv->gproxy);
+	proxy = egg_dbus_proxy_get_proxy (screensaver->priv->gproxy);
 	if (proxy == NULL) {
-		gpm_warning ("not connected");
+		egg_warning ("not connected");
 		return FALSE;
 	}
 
-	gpm_debug ("doing gnome-screensaver lock");
+	egg_debug ("doing gnome-screensaver lock");
 	dbus_g_proxy_call_no_reply (proxy, "Lock", G_TYPE_INVALID);
 
 	/* When we send the Lock signal to g-ss it takes maybe a second
@@ -284,19 +286,19 @@ gpm_screensaver_add_throttle (GpmScreensaver *screensaver,
 	guint32  cookie;
 	DBusGProxy *proxy;
 
-	g_return_val_if_fail (GPM_IS_SCREENSAVER (screensaver), FALSE);
+	g_return_val_if_fail (GPM_IS_SCREENSAVER (screensaver), 0);
 	g_return_val_if_fail (reason != NULL, 0);
 
-	proxy = dbus_proxy_get_proxy (screensaver->priv->gproxy);
+	proxy = egg_dbus_proxy_get_proxy (screensaver->priv->gproxy);
 	if (proxy == NULL) {
-		gpm_warning ("not connected");
-		return FALSE;
+		egg_warning ("not connected");
+		return 0;
 	}
 
 	/* shouldn't be, but make sure proxy valid */
 	if (proxy == NULL) {
-		gpm_warning ("g-s proxy is NULL!");
-		return FALSE;
+		egg_warning ("g-s proxy is NULL!");
+		return 0;
 	}
 
 	ret = dbus_g_proxy_call (proxy, "Throttle", &error,
@@ -306,16 +308,16 @@ gpm_screensaver_add_throttle (GpmScreensaver *screensaver,
 				 G_TYPE_UINT, &cookie,
 				 G_TYPE_INVALID);
 	if (error) {
-		gpm_debug ("ERROR: %s", error->message);
+		egg_debug ("ERROR: %s", error->message);
 		g_error_free (error);
 	}
-	if (ret == FALSE) {
+	if (!ret) {
 		/* abort as the DBUS method failed */
-		gpm_warning ("Throttle failed!");
+		egg_warning ("Throttle failed!");
 		return 0;
 	}
 
-	gpm_debug ("adding throttle reason: '%s': id %u", reason, cookie);
+	egg_debug ("adding throttle reason: '%s': id %u", reason, cookie);
 	return cookie;
 }
 
@@ -329,24 +331,24 @@ gpm_screensaver_remove_throttle (GpmScreensaver *screensaver,
 
 	g_return_val_if_fail (GPM_IS_SCREENSAVER (screensaver), FALSE);
 
-	proxy = dbus_proxy_get_proxy (screensaver->priv->gproxy);
+	proxy = egg_dbus_proxy_get_proxy (screensaver->priv->gproxy);
 	if (proxy == NULL) {
-		gpm_warning ("not connected");
+		egg_warning ("not connected");
 		return FALSE;
 	}
 
-	gpm_debug ("removing throttle: id %u", cookie);
+	egg_debug ("removing throttle: id %u", cookie);
 	ret = dbus_g_proxy_call (proxy, "UnThrottle", &error,
 				 G_TYPE_UINT, cookie,
 				 G_TYPE_INVALID,
 				 G_TYPE_INVALID);
 	if (error) {
-		gpm_debug ("ERROR: %s", error->message);
+		egg_debug ("ERROR: %s", error->message);
 		g_error_free (error);
 	}
-	if (ret == FALSE) {
+	if (!ret) {
 		/* abort as the DBUS method failed */
-		gpm_warning ("UnThrottle failed!");
+		egg_warning ("UnThrottle failed!");
 		return FALSE;
 	}
 
@@ -368,9 +370,9 @@ gpm_screensaver_check_running (GpmScreensaver *screensaver)
 
 	g_return_val_if_fail (GPM_IS_SCREENSAVER (screensaver), FALSE);
 
-	proxy = dbus_proxy_get_proxy (screensaver->priv->gproxy);
+	proxy = egg_dbus_proxy_get_proxy (screensaver->priv->gproxy);
 	if (proxy == NULL) {
-		gpm_warning ("not connected");
+		egg_warning ("not connected");
 		return FALSE;
 	}
 
@@ -379,7 +381,7 @@ gpm_screensaver_check_running (GpmScreensaver *screensaver)
 				 G_TYPE_BOOLEAN, &temp,
 				 G_TYPE_INVALID);
 	if (error) {
-		gpm_debug ("ERROR: %s", error->message);
+		egg_debug ("ERROR: %s", error->message);
 		g_error_free (error);
 	}
 
@@ -401,13 +403,13 @@ gpm_screensaver_poke (GpmScreensaver *screensaver)
 
 	g_return_val_if_fail (GPM_IS_SCREENSAVER (screensaver), FALSE);
 
-	proxy = dbus_proxy_get_proxy (screensaver->priv->gproxy);
+	proxy = egg_dbus_proxy_get_proxy (screensaver->priv->gproxy);
 	if (proxy == NULL) {
-		gpm_warning ("not connected");
+		egg_warning ("not connected");
 		return FALSE;
 	}
 
-	gpm_debug ("poke");
+	egg_debug ("poke");
 	dbus_g_proxy_call_no_reply (proxy,
 				    "SimulateUserActivity",
 				    G_TYPE_INVALID);
@@ -430,9 +432,9 @@ gpm_screensaver_get_idle (GpmScreensaver *screensaver, gint *time_secs)
 	g_return_val_if_fail (GPM_IS_SCREENSAVER (screensaver), FALSE);
 	g_return_val_if_fail (time != NULL, FALSE);
 
-	proxy = dbus_proxy_get_proxy (screensaver->priv->gproxy);
+	proxy = egg_dbus_proxy_get_proxy (screensaver->priv->gproxy);
 	if (proxy == NULL) {
-		gpm_warning ("not connected");
+		egg_warning ("not connected");
 		return FALSE;
 	}
 
@@ -441,12 +443,12 @@ gpm_screensaver_get_idle (GpmScreensaver *screensaver, gint *time_secs)
 				 G_TYPE_UINT, time_secs,
 				 G_TYPE_INVALID);
 	if (error) {
-		gpm_debug ("ERROR: %s", error->message);
+		egg_debug ("ERROR: %s", error->message);
 		g_error_free (error);
 	}
-	if (ret == FALSE) {
+	if (!ret) {
 		/* abort as the DBUS method failed */
-		gpm_warning ("GetActiveTime failed!");
+		egg_warning ("GetActiveTime failed!");
 		return FALSE;
 	}
 
@@ -542,15 +544,14 @@ static void
 gpm_screensaver_init (GpmScreensaver *screensaver)
 {
 	DBusGProxy *proxy;
+	DBusGConnection *connection;
 
 	screensaver->priv = GPM_SCREENSAVER_GET_PRIVATE (screensaver);
 
-	screensaver->priv->gproxy = dbus_proxy_new ();
-	proxy = dbus_proxy_assign (screensaver->priv->gproxy,
-				  DBUS_PROXY_SESSION,
-				  GS_LISTENER_SERVICE,
-				  GS_LISTENER_PATH,
-				  GS_LISTENER_INTERFACE);
+	screensaver->priv->gproxy = egg_dbus_proxy_new ();
+	connection = dbus_g_bus_get (DBUS_BUS_SESSION, NULL);
+	proxy = egg_dbus_proxy_assign (screensaver->priv->gproxy, connection, GS_LISTENER_SERVICE,
+				       GS_LISTENER_PATH, GS_LISTENER_INTERFACE);
 
 	g_signal_connect (screensaver->priv->gproxy, "proxy-status",
 			  G_CALLBACK (proxy_status_cb),
@@ -558,13 +559,17 @@ gpm_screensaver_init (GpmScreensaver *screensaver)
 
 	gpm_screensaver_proxy_connect_more (screensaver);
 
-	screensaver->priv->conf = gpm_conf_new ();
-	g_signal_connect (screensaver->priv->conf, "value-changed",
-			  G_CALLBACK (gconf_key_changed_cb), screensaver);
+	screensaver->priv->conf = gconf_client_get_default ();
+
+	/* watch gnome-screensaver keys */
+	gconf_client_add_dir (screensaver->priv->conf, GS_CONF_DIR,
+			      GCONF_CLIENT_PRELOAD_NONE, NULL);
+	gconf_client_notify_add (screensaver->priv->conf, GS_CONF_DIR,
+				 (GConfClientNotifyFunc) gpm_conf_gconf_key_changed_cb,
+				 screensaver, NULL, NULL);
 
 	/* get value of delay in g-s-p */
-	gpm_conf_get_uint (screensaver->priv->conf, GS_PREF_IDLE_DELAY,
-			   &screensaver->priv->idle_delay);
+	screensaver->priv->idle_delay = gconf_client_get_int (screensaver->priv->conf, GS_PREF_IDLE_DELAY, NULL);
 }
 
 /**
